@@ -26,8 +26,8 @@ from calculate.lib.utils.files import (isMount, process,
                                        getRunCommands, STDOUT, childMounts,
                                        getLoopFromPath,
                                        getMdRaidDevices, listDirectory,
-                                       removeDir,
-                                       makeDirectory, getProgPath)
+                                       removeDir, rsync_files, RsyncOptions,
+                                       makeDirectory, getProgPath, FilesError)
 from calculate.lib.utils.common import (mountEcryptfs,
                                         CommonError, isBootstrapDataOnly)
 
@@ -339,3 +339,15 @@ class Desktop(MethodsInterface):
             return True
         else:
             return False
+
+    def syncSkel(self, ur_home_path, uid, gid):
+        """
+        Скопировать содержимое /etc/skel в каталог пользователя
+        """
+        try:
+            rsync_files('/etc/skel', ur_home_path,
+                        opts=(RsyncOptions.Archive,
+                              RsyncOptions.Chown(uid, gid),))
+        except FilesError as e:
+            raise DesktopError(str(e))
+        return True
